@@ -453,21 +453,17 @@ sub new
 				$self->{'cnt'}++;
 			}
 			#STEP 2:  FETCH THE EMBED URL:
-print STDERR "--look for embed: domain=$domain=\n";
 			if ($html =~ m#\<iframe\s+src\=\"($domain\/embed\/[^\"]+)#s) {
 				$url = $1  unless ($self->{'cnt'} > 0);
-print STDERR "----FOUND EMBED URL=$url=\n";
 			}
 		}
 	}
-print STDERR "---URL NOW=$url=\n";
 	if ($url =~ m#\/embed\/([^\/]+)$#) {
 		$self->{'id'} ||= $1;
 		print STDERR "-FETCHING EMBED URL=$url= ID=".$self->{'id'}."=\n"  if ($DEBUG);
 		$response = $ua->get($url);
 		if ($response->is_success) {
 			$html = $response->decoded_content;
-print STDERR "---success1\n";
 		} else {
 			print STDERR $response->status_line  if ($DEBUG);
 			my $no_wget = system('wget','-V');
@@ -503,7 +499,9 @@ print STDERR "---success1\n";
 	$self->{'Url'} = ($self->{'cnt'} > 0) ? $self->{'streams'}->[0] : '';
 	print STDERR "--SUCCESS: 1st stream=".$self->{'Url'}."= total=".$self->{'total'}."=\n"
 			if ($DEBUG && $self->{'cnt'} > 0);
-	print STDERR "\n--ID=".$self->{'id'}."=\n--TITLE=".$self->{'title'}."=\n--CNT=".$self->{'cnt'}."=\n--ICON=".$self->{'iconurl'}."=\n--1ST=".$self->{'Url'}."=\n--streams=".join('|',@{$self->{'streams'}})."=\n"  if ($DEBUG);
+	print STDERR "\n--ID=".$self->{'id'}."=\n--TITLE=".$self->{'title'}."=\n--CNT="
+			.$self->{'cnt'}."=\n--ICON=".$self->{'iconurl'}."=\n--1ST=".$self->{'Url'}
+			."=\n--streams=".join('|',@{$self->{'streams'}})."=\n"  if ($DEBUG);
 	$self->_log($url);
 
 	bless $self, $class;   #BLESS IT!
@@ -511,10 +509,4 @@ print STDERR "---success1\n";
 	return $self;
 }
 
-sub getImageData
-{
-	my $self = shift;
-	return $self->getIconData();
-}
-
 1
